@@ -5,13 +5,13 @@ February 24, 2017
 Brett Alistair Kromkamp (brettkromkamp@gmail.com)
 """
 
+# region Module and Class Imports
 from __future__ import annotations
 
+import sqlite3
 from collections import namedtuple
 from datetime import datetime
-from typing import Optional, List, Union, Dict, Tuple
-
-from typedtree.tree import Tree  # type: ignore
+from typing import Dict, List, Optional, Tuple, Union
 
 from topicdb.core.models.association import Association
 from topicdb.core.models.attribute import Attribute
@@ -21,17 +21,17 @@ from topicdb.core.models.collaborator import Collaborator
 from topicdb.core.models.datatype import DataType
 from topicdb.core.models.doublekeydict import DoubleKeyDict
 from topicdb.core.models.language import Language
+from topicdb.core.models.map import Map
 from topicdb.core.models.member import Member
 from topicdb.core.models.occurrence import Occurrence
 from topicdb.core.models.topic import Topic
-from topicdb.core.models.map import Map
-from topicdb.core.store.retrievalmode import RetrievalMode
 from topicdb.core.store.ontologymode import OntologyMode
+from topicdb.core.store.retrievalmode import RetrievalMode
 from topicdb.core.topicdberror import TopicDbError
+from typedtree.tree import Tree  # type: ignore
 
-import sqlite3
-
-
+# endregion
+# region Constants
 TopicRefs = namedtuple("TopicRefs", ["instance_of", "role_spec", "topic_ref"])
 
 _UNIVERSAL_SCOPE = "*"
@@ -129,9 +129,10 @@ CREATE VIRTUAL TABLE IF NOT EXISTS text USING fts5 (
     resource_data
 );
 """
-
-
+# endregion
+# region Class
 class TopicStore:
+    # region Initialisation
     def __init__(self, database_path=_DATABASE_PATH) -> None:
         self.database_path = database_path
 
@@ -177,8 +178,8 @@ class TopicStore:
             "nld": "Dutch Language",
         }
 
-    # ========== ASSOCIATION ==========
-
+    # endregion
+    # region Association
     @staticmethod
     def _resolve_topic_refs(association: Association) -> List[TopicRefs]:
         result: List[TopicRefs] = []
@@ -427,8 +428,8 @@ class TopicStore:
             connection.close()
         self.create_attributes(map_identifier, association.attributes)
 
-    # ========== ATTRIBUTE ==========
-
+    # endregion
+    # region Attribute
     def attribute_exists(self, map_identifier: int, entity_identifier: str, name: str) -> bool:
         result = False
 
@@ -625,8 +626,8 @@ class TopicStore:
         finally:
             connection.close()
 
-    # ========== OCCURRENCE ==========
-
+    # endregion
+    # region Occurrence
     def delete_occurrence(self, map_identifier: int, identifier: str) -> None:
         connection = sqlite3.connect(self.database_path)
         try:
@@ -942,8 +943,8 @@ class TopicStore:
         finally:
             connection.close()
 
-    # ========== TAG ==========
-
+    # endregion
+    # region Tag
     def get_tags(self, map_identifier: int, identifier: str) -> List[Optional[str]]:
         result = []
 
@@ -997,8 +998,8 @@ class TopicStore:
         for tag in tags:
             self.create_tag(map_identifier, identifier, tag)
 
-    # ========== TOPIC ==========
-
+    # endregion
+    # region Topic
     @staticmethod
     def _normalize_topic_name(topic_identifier):
         return " ".join([word.capitalize() for word in topic_identifier.split("-")])
@@ -1902,8 +1903,8 @@ class TopicStore:
             connection.close()
         return result
 
-    # ========== DATABASE ==========
-
+    # endregion
+    # region Database
     def create_database(self):
         statements = _DDL.split(";")
 
@@ -1917,8 +1918,8 @@ class TopicStore:
         finally:
             connection.close()
 
-    # ========== TOPIC MAP ==========
-
+    # endregion
+    # region Topic Map
     def populate_map(self, map_identifier: int, user_identifier: int) -> None:
         map = self.get_map(map_identifier, user_identifier)
 
@@ -2218,8 +2219,8 @@ class TopicStore:
             connection.close()
         return result
 
-    # ========== COLLABORATION ==========
-
+    # endregion
+    # region Collaboration
     def collaborate(
         self,
         map_identifier: int,
@@ -2350,8 +2351,8 @@ class TopicStore:
             connection.close()
         return result
 
-    # ========== STATISTICS ==========
-
+    # endregion
+    # region Statistics
     def get_topic_occurrences_statistics(self, map_identifier: int, identifier: str, scope: str = None) -> Dict:
         result = {
             "image": 0,
@@ -2365,17 +2366,18 @@ class TopicStore:
         }
 
         connection = sqlite3.connect(self.database_path)
+        connection.row_factory = sqlite3.Row
         cursor = connection.cursor()
         try:
             if scope:
                 cursor.execute(
-                    "SELECT instance_of, COUNT(identifier) FROM occurrence GROUP BY map_identifier, topic_identifier, instance_of, scope HAVING map_identifier = ? AND topic_identifier = ? AND scope = ?",
+                    "SELECT instance_of, COUNT(identifier) AS count FROM occurrence GROUP BY map_identifier, topic_identifier, instance_of, scope HAVING map_identifier = ? AND topic_identifier = ? AND scope = ?",
                     (map_identifier, identifier, scope),
                 )
                 records = cursor.fetchall()
             else:
                 cursor.execute(
-                    "SELECT instance_of, COUNT(identifier) FROM occurrence GROUP BY map_identifier, topic_identifier, instance_of HAVING map_identifier = ? AND topic_identifier = ?",
+                    "SELECT instance_of, COUNT(identifier) AS count FROM occurrence GROUP BY map_identifier, topic_identifier, instance_of HAVING map_identifier = ? AND topic_identifier = ?",
                     (map_identifier, identifier),
                 )
                 records = cursor.fetchall()
@@ -2387,3 +2389,8 @@ class TopicStore:
             cursor.close()
             connection.close()
         return result
+
+    # endregion
+
+
+# endregion
